@@ -132,6 +132,7 @@ class ProjectsMixin(object):
         project_id=None,
         keep_ids=False,
         import_app_nav_bar=True,
+        import_default_sort=True,
         import_dashboards=True,
         import_dashboard_widgets=True,
         import_dashboard_loaders=True,
@@ -148,6 +149,7 @@ class ProjectsMixin(object):
         import_machinelearning_models=True,
         import_project_configuration=True,
         import_project_configuration_values=True,
+        import_project_translations=True,
         import_smartfilters=True,
         import_sources=True,
         import_sources_dataloader_plugins=True,
@@ -179,6 +181,8 @@ class ProjectsMixin(object):
             across multiple Squirro servers.
         :param import_app_nav_bar: Boolean. Whether to include the
             app & nav bar. Defaults to `True`.
+        :param import_default_sort: Boolean. Whether to include the
+            project default sort settings. Defaults to `True`.
         :param keep_ids: Boolean. Whether to try to create entities
             (project_id, dashboards, sources) with the same ID as the original's project
         :param import_dashboards: Boolean. Whether to include the dashboards,
@@ -218,6 +222,8 @@ class ProjectsMixin(object):
             project configuration, defaults to `True`.
         :param import_project_configuration_values: Boolean. Whether to include
             the import_project_configuration_values, defaults to `True`.
+        :param import_project_translations: Boolean. Whether to include the
+            project translations, defaults to `True`.
         :param import_smartfilters: Boolean. Whether to include the
             smartfilters, defaults to `True`.
         :param import_sources: Boolean. Whether to include the sources,
@@ -263,6 +269,7 @@ class ProjectsMixin(object):
 
         import_options = {
             "import_app_nav_bar": import_app_nav_bar,
+            "import_default_sort": import_default_sort,
             "import_dashboards": import_dashboards,
             "import_dashboard_widgets": import_dashboard_widgets,
             "import_dashboard_loaders": import_dashboard_loaders,
@@ -278,6 +285,7 @@ class ProjectsMixin(object):
             "import_pipeline_workflows": import_pipeline_workflows,
             "import_project_configuration": import_project_configuration,
             "import_project_configuration_values": import_project_configuration_values,
+            "import_project_translations": import_project_translations,
             "import_smartfilters": import_smartfilters,
             "import_sources": import_sources,
             "import_sources_dataloader_plugins": import_sources_dataloader_plugins,
@@ -406,6 +414,7 @@ class ProjectsMixin(object):
         self,
         project_id,
         export_app_nav_bar=True,
+        export_default_sort=True,
         export_dashboards=True,
         export_dashboard_widgets=True,
         export_dashboard_loaders=True,
@@ -422,6 +431,7 @@ class ProjectsMixin(object):
         export_machinelearning_models=True,
         export_project_configuration=True,
         export_project_configuration_values=True,
+        export_project_translations=True,
         export_smartfilters=True,
         export_sources=True,
         export_sources_dataloader_plugins=True,
@@ -469,6 +479,8 @@ class ProjectsMixin(object):
         :param project_id: Project identifier.
         :param export_app_nav_bar: Boolean. Whether to include the
             app & nav bar. Defaults to `True`.
+        :param export_default_sort: Boolean. Whether to include the
+        default_sort. Defaults to `True`.
         :param export_dashboards: Boolean. Whether to include the dashboards,
             defaults to `True`.
         :param export_dashboard_widgets: Boolean. Whether to include the
@@ -504,6 +516,8 @@ class ProjectsMixin(object):
             project configuration, defaults to `True`.
         :param export_project_configuration_values: Boolean. Whether to include
             the export_project_configuration_values, defaults to `True`.
+        :param export_project_translations: Boolean. Whether to include the
+            project translations, defaults to `True`.
         :param export_smartfilters: Boolean. Whether to include the
             smartfilters, defaults to `True`.
         :param export_sources: Boolean. Whether to include the sources,
@@ -540,6 +554,7 @@ class ProjectsMixin(object):
 
         export_options = {
             "export_app_nav_bar": export_app_nav_bar,
+            "export_default_sort": export_default_sort,
             "export_dashboards": export_dashboards,
             "export_dashboard_widgets": export_dashboard_widgets,
             "export_dashboard_loaders": export_dashboard_loaders,
@@ -555,6 +570,7 @@ class ProjectsMixin(object):
             "export_pipeline_workflows": export_pipeline_workflows,
             "export_project_configuration": export_project_configuration,
             "export_project_configuration_values": export_project_configuration_values,
+            "export_project_translations": export_project_translations,
             "export_smartfilters": export_smartfilters,
             "export_sources": export_sources,
             "export_sources_dataloader_plugins": export_sources_dataloader_plugins,
@@ -634,6 +650,7 @@ class ProjectsMixin(object):
         project_id,
         project_archive,
         import_app_nav_bar=True,
+        import_default_sort=True,
         import_dashboards=True,
         import_dashboard_widgets=True,
         import_dashboard_loaders=True,
@@ -650,6 +667,7 @@ class ProjectsMixin(object):
         import_machinelearning_models=True,
         import_project_configuration=True,
         import_project_configuration_values=True,
+        import_project_translations=True,
         import_smartfilters=True,
         import_sources=True,
         import_sources_dataloader_plugins=True,
@@ -694,6 +712,8 @@ class ProjectsMixin(object):
         :param project_archive: Path to project archive.
         :param import_app_nav_bar: Boolean. Whether to include the
             app & nav bar. Defaults to `True`.
+        :param import_default_sort: Boolean. Whether to include the
+            project default sort. Defaults to `True`.
         :param import_dashboards: Boolean. Whether to include the dashboards,
             defaults to `True`.
         :param import_dashboard_widgets: Boolean. Whether to include the
@@ -730,6 +750,8 @@ class ProjectsMixin(object):
             project configuration, defaults to `True`.
         :param import_project_configuration_values: Boolean. Whether to include
             the import_project_configuration_values, defaults to `True`.
+        :param import_project_translations: Boolean. Whether to include the
+            project translations, defaults to `True`.
         :param import_smartfilters: Boolean. Whether to include the
             smartfilters, defaults to `True`.
         :param import_sources: Boolean. Whether to include the sources,
@@ -762,6 +784,7 @@ class ProjectsMixin(object):
 
         import_options = {
             "import_app_nav_bar": import_app_nav_bar,
+            "import_default_sort": import_default_sort,
             "import_dashboards": import_dashboards,
             "import_dashboard_widgets": import_dashboard_widgets,
             "import_dashboard_loaders": import_dashboard_loaders,
@@ -777,6 +800,7 @@ class ProjectsMixin(object):
             "import_pipeline_workflows": import_pipeline_workflows,
             "import_project_configuration": import_project_configuration,
             "import_project_configuration_values": import_project_configuration_values,
+            "import_project_translations": import_project_translations,
             "import_smartfilters": import_smartfilters,
             "import_sources": import_sources,
             "import_sources_dataloader_plugins": import_sources_dataloader_plugins,
